@@ -87,6 +87,13 @@ class RebuildHandlerWrapper(object):
         class RebuildHandler(SimpleHTTPRequestHandler):
             """Rebuild if something has changed."""
 
+            timeout = 30
+
+            def setup(self):
+                "Sets a timeout on the socket"
+                self.request.settimeout(self.timeout)
+                SimpleHTTPRequestHandler.setup(self)
+
             def handle(self):
                 """
                 Handle a request and, if anything has changed, rebuild the
@@ -105,7 +112,7 @@ class RebuildHandlerWrapper(object):
     def changed(self):
         """
         Returns if the contents of the monitored directories have changed since
-        the last call. It will return always return false on first run. 
+        the last call. It will return always return false on first run.
         """
         last_modtime_sum = self._modtime_sum
 
@@ -114,8 +121,9 @@ class RebuildHandlerWrapper(object):
         for d in self.watch_dirs:
             for root, dirs, files in os.walk(d):
                 for f in files:
-                    abspath = os.path.join(root, f)
-                    self._modtime_sum += os.stat(abspath).st_mtime
+                    if not f.startswith('.'):
+                        abspath = os.path.join(root, f)
+                        self._modtime_sum += os.stat(abspath).st_mtime
 
         if last_modtime_sum is None:
             # always return false on first run
